@@ -65,24 +65,30 @@ class Deployer(object):
         """
         queues = []
         for child in Queue.__subclasses__():
-            print(child.__name__)
             queues.append({"name": child.__name__.lower()})
         return queues
 
-    def _get_api_functions(self):
-        api_functions = []
-        api_classes = APIFunction.__subclasses__()
+    def _get_api_subclasses(self, api_functions, start_class):
+        api_classes = start_class.__subclasses__()
+        # Add any subclasses
         for api in api_classes:
             inst = api()
             methods = inst.get_methods()
-            api_functions.append(
-                {
-                    "class": api,
-                    "name": api.__name__,
-                    "endpoint": api.endpoint,
-                    "methods": methods,
-                }
-            )
+            if hasattr(inst, "is_lambda"):
+                api_functions.append(
+                    {
+                        "class": api,
+                        "name": api.__name__,
+                        "endpoint": api.endpoint,
+                        "methods": methods,
+                    }
+                )
+            else:
+                self._get_api_subclasses(api_functions, api)
+
+    def _get_api_functions(self):
+        api_functions = []
+        self._get_api_subclasses(api_functions, APIFunction)
         return api_functions
 
     def _get_queue_functions(self):
@@ -275,7 +281,7 @@ class Deployer(object):
             _ = sqs.create_queue(QueueName=f"legoon-{queue['name']}-prod")
 
         try:
-            role = iam.create_role(
+            _ = iam.create_role(
                 RoleName="lambda",
                 AssumeRolePolicyDocument=json.dumps(
                     {
@@ -290,7 +296,6 @@ class Deployer(object):
                     }
                 ),
             )
-            print(role)
         except Exception:
             print("Role exists.")
 
@@ -393,7 +398,8 @@ class Deployer(object):
         subprocess.run(sam_start, cwd=self.dir, check=True)
 
     def _handle_response(self, func, method, *args, **kwargs):
-        event = {"httpMethod": method, "pathParameters": {}}
+        body = bottle.request.body.read()
+        event = {"httpMethod": method, "pathParameters": {}, "body": body}
         for kwarg, val in kwargs.items():
             event["pathParameters"][kwarg] = val
         res = func(event, {})
@@ -406,7 +412,6 @@ class Deployer(object):
     def _start_api_local(self):
         self._source_files()
         api_functions = self._get_api_functions()
-        print(api_functions)
 
         @bottle.route("/test")
         def test():
